@@ -62,7 +62,7 @@ function set_tag_data(&$tag) {
     /* ɥᥤ */
     $domain = "";
     if (isset($add_data["domain"]) === TRUE) {
-        $domain = htmlspecialchars($add_data["domain"]);
+        $domain = escape_html($add_data["domain"]);
     }
 
     /* ѥ */
@@ -79,7 +79,7 @@ function set_tag_data(&$tag) {
     /* ̥ѥ */
     $indivipass = "";
     if (isset($add_data["indivipass"]) === TRUE) {
-        $indivipass = htmlspecialchars($add_data["indivipass"]);
+        $indivipass = escape_html($add_data["indivipass"]);
     }
 
     /* Ź沽롼 */
@@ -235,7 +235,7 @@ if (isset($_POST["add"]) === TRUE) {
 /* 󥻥 */
 } elseif (isset($_POST["cancel"]) === TRUE) {
     /* ɲò̤ */
-    dgp_location("index.php", $del_list);
+    dgp_location("index.php");
     exit (0);
 
 }
