@@ -93,7 +93,7 @@ function print_result(&$looptag)
         }
 
         /*  */
-        $domain = htmlspecialchars($domain);
+        $domain = escape_html($domain);
         $cnv_key = str_replace("'", "\'", $key);
 
         $looptag[$domain_count]["<<KEY>>"] = $key;
@@ -140,7 +140,7 @@ if ($ret === FALSE) {
 
 /* å */
 if (isset($_POST["msg"]) === TRUE) {
-    $err_msg = htmlspecialchars($_POST["msg"]);
+    $err_msg = escape_html($_POST["msg"]);
 }
 
 /***********************************************************
@@ -169,7 +169,7 @@ if (isset($_POST["delete"]) === TRUE) {
 /* ɲ */
 if (isset($_POST["new_add"]) === TRUE) {
     /* ɲò̤ */
-    dgp_location("add.php", $del_list);
+    dgp_location("add.php");
     exit (0);
 
 /* åΤ */
