@@ -61,7 +61,7 @@ function set_tag_data(&$tag) {
 
     /* ɥᥤ̾ */
     if (isset($sender_name) === TRUE) {
-        $domain = htmlspecialchars($sender_name);
+        $domain = escape_html($sender_name);
     }
     $tag["<<DOMAIN>>"] = $domain;
 
@@ -251,7 +251,7 @@ if (isset($_POST["add"]) === TRUE) {
 } elseif (isset($_POST["cancel"]) === TRUE) {
 
     /* ɥᥤ̤ */
-    dgp_location("index.php", $del_list);
+    dgp_location("index.php");
     exit (0);
 }
 
