@@ -83,17 +83,17 @@ function display_body(&$tag) {
     $hiddendata['name_match'] = $_POST['name_match'];
 
     /* 桼̾ */
-    $user = htmlspecialchars($dispusr);
+    $user = escape_html($dispusr);
 
     /* ɥᥤ̾ */
     $domain = "";
     if (isset($mod_data["domain"]) === TRUE) {
-        $domain = htmlspecialchars($mod_data["domain"]);
+        $domain = escape_html($mod_data["domain"]);
     }
 
     $disp_dom = "";
     if (isset($mod_data["disp_dom"]) === TRUE) {
-        $disp_dom = htmlspecialchars($mod_data["disp_dom"]);
+        $disp_dom = escape_html($mod_data["disp_dom"]);
     }
 
     /* ѥ */
@@ -110,7 +110,7 @@ function display_body(&$tag) {
     /* ̥ѥ */
     $indivipass = "";
     if (isset($mod_data["indivipass"]) === TRUE) {
-        $indivipass = htmlspecialchars($mod_data["indivipass"]);
+        $indivipass = escape_html($mod_data["indivipass"]);
     }
 
     /* Ź沽롼 */
@@ -137,7 +137,7 @@ EOD;
     /* hidden */
     $hidden_data = "";
     foreach($hiddendata as $hidkey => $hidval) {
-        $hidval = htmlspecialchars($hidval);
+        $hidval = escape_html($hidval);
         $hidden_data .=<<<EOD
   <input type="hidden" name="{$hidkey}" value="{$hidval}">
 EOD;
@@ -242,7 +242,7 @@ $form_name = $_POST["form_name"];
 $name_match = $_POST["name_match"];
 
 $dispusr = $web_conf[$url_data['script']]['displayuser'];
-$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);
+$dispusr = escape_html($ldapdata[0][$dispusr][0]);
 
 /* ݻͼ */
 $del_list = "";
@@ -328,7 +328,7 @@ if (isset($_POST["mod"]) === TRUE) {
 /* 󥻥 */
 } elseif (isset($_POST["cancel"]) === TRUE) {
     /* ̤ */
-    page_location_search("samma_list.php", $del_list);
+    page_location_search("samma_list.php");
     exit (0);
 
 }
