@@ -65,19 +65,19 @@ function set_tag_data(&$tag) {
     global $dispusr;
 
     /* 桼̾ */
-    $user = htmlspecialchars($dispusr);
+    $user = escape_html($dispusr);
     $tag["<<USER>>"] = $user;
 
     /* ɥᥤ̾ */
     $domain = "";
     if (isset($mod_data["domain"]) === TRUE) {
-        $domain = htmlspecialchars($mod_data["domain"]);
+        $domain = escape_html($mod_data["domain"]);
     }
     $tag["<<DOMAIN>>"] = $domain;
 
     $disp_dom = "";
     if (isset($mod_data["disp_dom"]) === TRUE) {
-        $disp_dom = htmlspecialchars($mod_data["disp_dom"]);
+        $disp_dom = escape_html($mod_data["disp_dom"]);
     }
     $tag["<<DISP_DOM>>"] = $disp_dom;
 
@@ -97,7 +97,7 @@ function set_tag_data(&$tag) {
     /* ̥ѥ */
     $indivipass = "";
     if (isset($mod_data["indivipass"]) === TRUE) {
-        $indivipass = htmlspecialchars($mod_data["indivipass"]);
+        $indivipass = escape_html($mod_data["indivipass"]);
     }
     $tag["<<INDIVIPASS>>"] = $indivipass;
 
@@ -153,7 +153,7 @@ if ($ret === FALSE) {
 }
 
 $dispusr = $web_conf[$url_data['script']]['displayuser'];
-$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);
+$dispusr = escape_html($ldapdata[0][$dispusr][0]);
 
 /* ݻͼ */
 $del_list = "";
@@ -252,7 +252,7 @@ if (isset($_POST["mod"]) === TRUE) {
 /* 󥻥 */
 } elseif (isset($_POST["cancel"]) === TRUE) {
     /* ̤ */
-    dgp_location("index.php", $del_list);
+    dgp_location("index.php");
     exit (0);
 
 }
